[Libreoffice-commits] core.git: sd/source

2013-03-21 Thread Urs Fässler
 sd/source/core/stlsheet.cxx  |  113 +--
 sd/source/filter/eppt/eppt.cxx   |6 +-
 sd/source/filter/eppt/epptso.cxx |9 +--
 3 files changed, 48 insertions(+), 80 deletions(-)

New commits:
commit 08416ff716119dca888087bd38fd9662f4e85f7a
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Mar 21 09:12:38 2013 +0100

translated last missed german comments in sd/

Change-Id: I48102b5e4d41ba786e9f9476b480715d5756ab87

diff --git a/sd/source/core/stlsheet.cxx b/sd/source/core/stlsheet.cxx
index bb0e558..ccd29d8 100644
--- a/sd/source/core/stlsheet.cxx
+++ b/sd/source/core/stlsheet.cxx
@@ -144,7 +144,7 @@ SdStyleSheet::SdStyleSheet( const SdStyleSheet  r )
 SdStyleSheet::~SdStyleSheet()
 {
 delete pSet;
-pSet = NULL;// damit nachfolgende Destruktoren eine Chance haben
+pSet = NULL;// that following destructors also get a change
 }
 
 void SdStyleSheet::SetApiName( const OUString rApiName )
@@ -165,31 +165,19 @@ void SdStyleSheet::Load (SvStream rIn, sal_uInt16 
nVersion)
 {
 SfxStyleSheetBase::Load(rIn, nVersion);
 
-// Die Default-Maske war frueher 0xAFFE.
-// Aus dieser Default-Maske wurden die benoetigten Flags ausmaskiert.
-// Nun wurde das Flag SFXSTYLEBIT_READONLY eingefuehrt, was dazu
-// das alle StyleSheets read-only waren.
-// Da im Draw kein StyleSheet read-only sein soll, wird an dieser Stelle
-// das Flag zurueckgesetzt.
+/* previously, the default mask was 0xAFFE. The needed flags were masked
+   from this mask. Now the flag SFXSTYLEBIT_READONLY was introduced and 
with
+   this, all style sheets are read only. Since no style sheet should be 
read
+   only in Draw, we reset the flag here.  */
 nMask = ~SFXSTYLEBIT_READONLY;
 }
 
-/*
-|*
-|* Store
-|*
-\/
 
 void SdStyleSheet::Store(SvStream rOut)
 {
 SfxStyleSheetBase::Store(rOut);
 }
 
-/*
-|*
-|* Parent setzen
-|*
-\/
 
 bool SdStyleSheet::SetParent(const String rParentName)
 {
@@ -197,7 +185,7 @@ bool SdStyleSheet::SetParent(const String rParentName)
 
 if (SfxStyleSheet::SetParent(rParentName))
 {
-// PseudoStyleSheets haben keine eigenen ItemSets
+// PseudoStyleSheets do not have their own ItemSets
 if (nFamily != SD_STYLE_FAMILY_PSEUDO)
 {
 if( rParentName.Len() )
@@ -226,17 +214,14 @@ bool SdStyleSheet::SetParent(const String rParentName)
 return bResult;
 }
 
-/*
-|*
-|* ItemSet ggfs. erzeugen und herausreichen
-|*
-\/
-
+/**
+ * create if necessary and return ItemSets
+ */
 SfxItemSet SdStyleSheet::GetItemSet()
 {
 if (nFamily == SD_STYLE_FAMILY_GRAPHICS || nFamily == 
SD_STYLE_FAMILY_MASTERPAGE)
 {
-// ggfs. das ItemSet 'on demand' anlegen
+// we create the ItemSet 'on demand' if necessary
 if (!pSet)
 {
 sal_uInt16 nWhichPairTable[] = { XATTR_LINE_FIRST,  
XATTR_LINE_LAST,
@@ -288,8 +273,8 @@ SfxItemSet SdStyleSheet::GetItemSet()
 return *pSet;
 }
 
-// dies ist eine Stellvertretervorlage fuer die interne Vorlage des
-// aktuellen Praesentationslayouts: dessen ItemSet returnieren
+// this is a dummy template for the internal template of the
+// current presentation layout; return the ItemSet of that template
 else
 {
 
@@ -329,13 +314,10 @@ SfxItemSet SdStyleSheet::GetItemSet()
 }
 }
 
-/*
-|*
-|* IsUsed(), eine Vorlage gilt als benutzt, wenn sie von eingefuegten Objekten
-|*   oder von benutzten Vorlagen referenziert wird
-|*
-\/
-
+/**
+ * A template is used when it is referenced by inserted object or by a used
+ * template.
+ */
 bool SdStyleSheet::IsUsed() const
 {
 bool bResult = false;
@@ -378,12 +360,9 @@ bool SdStyleSheet::IsUsed() const
 return bResult;
 }
 
-/*
-|*
-|* das StyleSheet ermitteln, fuer das dieses StyleSheet steht
-|*
-\/
-
+/**
+ * Determine the style sheet for which this dummy is for.
+ */
 SdStyleSheet* SdStyleSheet::GetRealStyleSheet() const
 {
 OUString aRealStyle;
@@ -421,8 +400,8 @@ SdStyleSheet* SdStyleSheet::GetRealStyleSheet() const
 }
 else
 {
-// Noch keine Seite vorhanden
-// Dieses kann beim Aktualisieren vonDokumentvorlagen vorkommen
+   

[Libreoffice-commits] core.git: sd/source

2013-03-13 Thread Urs Fässler
 sd/source/ui/inc/BreakDlg.hxx |8 +
 sd/source/ui/inc/Client.hxx   |5 ---
 sd/source/ui/inc/ClientView.hxx   |   14 +++--
 sd/source/ui/inc/FrameView.hxx|   46 ++
 sd/source/ui/inc/GraphicDocShell.hxx  |9 +
 sd/source/ui/inc/LayerTabBar.hxx  |9 +
 sd/source/ui/inc/NavigatorChildWindow.hxx |9 +
 sd/source/ui/inc/OutlineBulletDlg.hxx |8 +
 sd/source/ui/inc/OutlineView.hxx  |7 +---
 sd/source/ui/inc/TabControl.hxx   |8 +
 sd/source/ui/inc/View.hxx |   16 +++---
 sd/source/ui/inc/ViewShell.hxx|   10 +++---
 sd/source/ui/inc/animobjs.hxx |9 +
 sd/source/ui/inc/assclass.hxx |   15 ++---
 sd/source/ui/inc/copydlg.hxx  |8 +
 sd/source/ui/inc/dlg_char.hxx |8 +
 sd/source/ui/inc/dlgctrls.hxx |9 +
 sd/source/ui/inc/dlgfield.hxx |9 +
 sd/source/ui/inc/dlgpage.hxx  |8 +
 sd/source/ui/inc/dlgsnap.hxx  |9 +
 sd/source/ui/inc/drawview.hxx |   11 ++-
 sd/source/ui/inc/fucon3d.hxx  |4 +-
 sd/source/ui/inc/fuconarc.hxx |4 +-
 sd/source/ui/inc/fuconbez.hxx |4 +-
 sd/source/ui/inc/fuconcs.hxx  |8 -
 sd/source/ui/inc/fuconrec.hxx |   13 +++-
 sd/source/ui/inc/fuconstr.hxx |   10 +-
 sd/source/ui/inc/fuconuno.hxx |   13 +++-
 sd/source/ui/inc/fudraw.hxx   |9 +
 sd/source/ui/inc/fudspord.hxx |   10 +-
 sd/source/ui/inc/fuediglu.hxx |   10 +-
 sd/source/ui/inc/fuinsfil.hxx |6 +--
 sd/source/ui/inc/fuolbull.hxx |9 +
 sd/source/ui/inc/fuoltext.hxx |8 +
 sd/source/ui/inc/fuoutl.hxx   |9 +
 sd/source/ui/inc/fupage.hxx   |4 +-
 sd/source/ui/inc/fupoor.hxx   |   32 
 sd/source/ui/inc/fusel.hxx|4 +-
 sd/source/ui/inc/futext.hxx   |   13 +++-
 sd/source/ui/inc/fuzoom.hxx   |4 +-
 sd/source/ui/inc/gluectrl.hxx |   17 +++
 sd/source/ui/inc/inspagob.hxx |   10 +-
 sd/source/ui/inc/navigatr.hxx |   18 +++
 sd/source/ui/inc/paragr.hxx   |8 +
 sd/source/ui/inc/present.hxx  |6 +--
 sd/source/ui/inc/prltempl.hxx |   12 +++
 sd/source/ui/inc/res_bmp.hrc  |   14 +++--
 sd/source/ui/inc/sdpopup.hxx  |9 +
 sd/source/ui/inc/sdpreslt.hxx |4 +-
 sd/source/ui/inc/sdtreelb.hxx |   29 +++---
 sd/source/ui/inc/strings.hrc  |2 -
 sd/source/ui/inc/tabtempl.hxx |8 +
 sd/source/ui/inc/tpaction.hxx |   17 +++
 sd/source/ui/inc/tpoption.hxx |   25 ++--
 sd/source/ui/inc/unprlout.hxx |2 -
 55 files changed, 219 insertions(+), 371 deletions(-)

New commits:
commit c1ba64c2d90dfe73eece410a86f630a0032d0ffe
Author: Urs Fässler u...@bitzgi.ch
Date:   Wed Mar 13 17:55:26 2013 +0100

translation and cleanup of comments in sd/source/ui/inc/

Change-Id: Ib1d1be4364c56e5164afc631c614183f15e20644

diff --git a/sd/source/ui/inc/BreakDlg.hxx b/sd/source/ui/inc/BreakDlg.hxx
index cc10478..be74b62 100644
--- a/sd/source/ui/inc/BreakDlg.hxx
+++ b/sd/source/ui/inc/BreakDlg.hxx
@@ -38,11 +38,9 @@ namespace sd {
 class DrawDocShell;
 class DrawView;
 
-/*
-|*
-|* Dialog zum aufbrechen von Metafiles
-|*
-\/
+/**
+ * dialog to break meta files
+ */
 class BreakDlg
 : public SfxModalDialog
 {
diff --git a/sd/source/ui/inc/Client.hxx b/sd/source/ui/inc/Client.hxx
index d01c075..a029f5a 100644
--- a/sd/source/ui/inc/Client.hxx
+++ b/sd/source/ui/inc/Client.hxx
@@ -30,11 +30,6 @@ namespace sd {
 
 class ViewShell;
 
-/*
-|*
-|* Client
-|*
-\/
 
 class Client : public SfxInPlaceClient
 {
diff --git a/sd/source/ui/inc/ClientView.hxx b/sd/source/ui/inc/ClientView.hxx
index d25ae2b..c3753c0 100644
--- a/sd/source/ui/inc/ClientView.hxx
+++ b/sd/source/ui/inc/ClientView.hxx
@@ -26,12 +26,9 @@ namespace sd {
 
 class DrawViewShell;
 
-/
-|*
-|* Die SdClientView wird fuer DrawDocShell::Draw() verwendet
-|*
-\/
-
+/**
+ * The SdClientView is used for DrawDocShell::Draw()
+ */
 class 

[Libreoffice-commits] core.git: sd/source

2013-03-13 Thread Urs Fässler
 sd/source/ui/dlg/gluectrl.cxx |2 
 sd/source/ui/func/fuconbez.cxx|2 
 sd/source/ui/func/fuediglu.cxx|8 -
 sd/source/ui/slideshow/showwin.cxx|   40 -
 sd/source/ui/slideshow/slideshowimpl.cxx  |   27 +--
 sd/source/ui/slidesorter/controller/SlideSorterController.cxx |4 
 sd/source/ui/slidesorter/controller/SlsSlotManager.cxx|   18 +-
 sd/source/ui/unoidl/DrawController.cxx|2 
 sd/source/ui/unoidl/sddetect.cxx  |2 
 sd/source/ui/unoidl/unolayer.cxx  |   16 +-
 sd/source/ui/unoidl/unomodel.cxx  |   70 --
 sd/source/ui/unoidl/unoobj.cxx|   10 -
 sd/source/ui/unoidl/unopage.cxx   |2 
 sd/source/ui/unoidl/unopback.cxx  |2 
 14 files changed, 84 insertions(+), 121 deletions(-)

New commits:
commit f4a37ca9584d7b8fcbd7aaa80162edcfde3cd4ed
Author: Urs Fässler u...@bitzgi.ch
Date:   Wed Mar 13 20:30:06 2013 +0100

several translations and fixes for translations

Change-Id: I47ca71d578f3e0b1e2c3499f0785d986ed4f583e

diff --git a/sd/source/ui/dlg/gluectrl.cxx b/sd/source/ui/dlg/gluectrl.cxx
index 04584e9..b1f760e 100644
--- a/sd/source/ui/dlg/gluectrl.cxx
+++ b/sd/source/ui/dlg/gluectrl.cxx
@@ -59,7 +59,7 @@ static sal_uInt16 aEscDirArray[] =
 SFX_IMPL_TOOLBOX_CONTROL( SdTbxCtlGlueEscDir, SfxUInt16Item )
 
 /**
- * Constructor for clue point escape direction Listbox
+ * Constructor for glue point escape direction Listbox
  */
 GlueEscDirLB::GlueEscDirLB( Window* pParent, const Reference XFrame  rFrame 
) :
 ListBox( pParent, WinBits( WB_BORDER | WB_DROPDOWN ) ),
diff --git a/sd/source/ui/func/fuconbez.cxx b/sd/source/ui/func/fuconbez.cxx
index 4ee9ca3..67727bc 100644
--- a/sd/source/ui/func/fuconbez.cxx
+++ b/sd/source/ui/func/fuconbez.cxx
@@ -118,7 +118,7 @@ sal_Bool FuConstructBezierPolygon::MouseButtonDown(const 
MouseEvent rMEvt)
 
 if (eHit == SDRHIT_MARKEDOBJECT  nEditMode == SID_BEZIER_INSERT)
 {
-// insert clue point
+// insert glue point
 mpView-BegInsObjPoint(aMDPos, rMEvt.IsMod1());
 }
 else
diff --git a/sd/source/ui/func/fuediglu.cxx b/sd/source/ui/func/fuediglu.cxx
index 8a98b58..e796e9d 100644
--- a/sd/source/ui/func/fuediglu.cxx
+++ b/sd/source/ui/func/fuediglu.cxx
@@ -121,12 +121,12 @@ sal_Bool FuEditGluePoints::MouseButtonDown(const 
MouseEvent rMEvt)
 }
 else if (eHit == SDRHIT_MARKEDOBJECT  mpView-IsInsGluePointMode())
 {
-// insert clue points
+// insert glue points
 mpView-BegInsGluePoint(aMDPos);
 }
 else if (eHit == SDRHIT_MARKEDOBJECT  rMEvt.IsMod1())
 {
-// select clue points
+// select glue points
 if (!rMEvt.IsShift())
 mpView-UnmarkAllGluePoints();
 
@@ -139,7 +139,7 @@ sal_Bool FuEditGluePoints::MouseButtonDown(const 
MouseEvent rMEvt)
 }
 else if (eHit == SDRHIT_GLUEPOINT)
 {
-// select clue points
+// select glue points
 if (!rMEvt.IsShift())
 mpView-UnmarkAllGluePoints();
 
@@ -181,7 +181,7 @@ sal_Bool FuEditGluePoints::MouseButtonDown(const 
MouseEvent rMEvt)
 }
 else if (mpView-AreObjectsMarked())
 {
-// select clue point
+// select glue point
 if (!rMEvt.IsShift())
 mpView-UnmarkAllGluePoints();
 
diff --git a/sd/source/ui/slideshow/showwin.cxx 
b/sd/source/ui/slideshow/showwin.cxx
index b00d4c3..13542df 100644
--- a/sd/source/ui/slideshow/showwin.cxx
+++ b/sd/source/ui/slideshow/showwin.cxx
@@ -64,7 +64,7 @@ ShowWindow::ShowWindow( const ::rtl::Reference SlideshowImpl 
 xController, ::
 aMap.SetMapUnit(MAP_100TH_MM);
 SetMapMode(aMap);
 
-// HelpId setzen
+// set HelpId
 SetHelpId( HID_SD_WIN_PRESENTATION );
 SetUniqueId( HID_SD_WIN_PRESENTATION );
 
@@ -85,11 +85,6 @@ ShowWindow::~ShowWindow(void)
 maMouseTimer.Stop();
 }
 
-/*
-|*
-|* Keyboard event
-|*
-\/
 
 void ShowWindow::KeyInput(const KeyEvent rKEvt)
 {
@@ -173,11 +168,6 @@ void ShowWindow::KeyInput(const KeyEvent rKEvt)
 mpViewShell-SetActiveWindow( this );
 }
 
-/*
-|*
-|* MouseButtonDown event
-|*
-\/
 
 void ShowWindow::MouseButtonDown(const MouseEvent /*rMEvt*/)
 {
@@ -191,11 +181,6 @@ void ShowWindow::MouseButtonDown(const MouseEvent 

[Libreoffice-commits] core.git: sd/source

2013-03-07 Thread Urs Fässler
 sd/source/ui/app/menuids_tmpl.src  |   24 
 sd/source/ui/app/sddll.cxx |8 
 sd/source/ui/app/sddll2.cxx|4 ++--
 sd/source/ui/app/sdxfer.cxx|4 ++--
 sd/source/ui/app/strings.src   |2 +-
 sd/source/ui/app/tbxids_tmpl.src   |6 +++---
 sd/source/ui/app/toolbox2_tmpl.src |6 +++---
 7 files changed, 27 insertions(+), 27 deletions(-)

New commits:
commit 32df45aeea30eb93c04e719b2a09e9313b912468
Author: Urs Fässler u...@bitzgi.ch
Date:   Fri Mar 1 15:52:56 2013 +0100

small translations of German comment in directory sd/source/ui/app

Change-Id: Ia24e98a57d2096729abfd1caaab895c689cac0fb

diff --git a/sd/source/ui/app/menuids_tmpl.src 
b/sd/source/ui/app/menuids_tmpl.src
index e71b628..f0d44c1 100644
--- a/sd/source/ui/app/menuids_tmpl.src
+++ b/sd/source/ui/app/menuids_tmpl.src
@@ -21,10 +21,10 @@
 #include helpids.h
 
 #define SEPARATOR   MenuItem { Separator = TRUE; };
- // DUMMY ist eine ID wo ein SubMenu folgt
- // (muss jeweils immer erhoeht werden!)
+ // DUMMY is a ID where a SubMenu is following
+ // (it has to be increased every time!)
 #define DUMMY 333
- // Nichtobjektbezogen
+ // not object related
 
 #define MN_DISTRIBUTE \
 MenuItem\
@@ -93,7 +93,7 @@
 Text [ en-US ] = ~Delete ; \
 };
 
- // Seiten-Attribute
+ // page attributes
 #define MN_MODIFY_PAGE \
 MenuItem\
 {\
@@ -270,7 +270,7 @@
 Text [ en-US ] = ~Rename Page ; \
 };
 
- // Grafik-Attribute
+ // graphic attributes
 #define MN_LINE \
 MenuItem\
 {\
@@ -343,7 +343,7 @@
 Text [ en-US ] = Edit ~Points ; \
 };
 
- // Anordnung
+ // arrangement
 #define MN_POSITION \
 MenuItem\
 {\
@@ -409,7 +409,7 @@
 };\
 };
 
- // Text-Elemente
+ // text elements
 #define MN_CHAR \
 MenuItem\
 {\
@@ -537,7 +537,7 @@
 Text [ en-US ] = S~pecial Character... ; \
 };
 
- // Text-Ausrichtung
+ // test orientation
 #define MN_TEXT_ALIGN\
 MenuItem\
 {\
@@ -580,7 +580,7 @@
 };\
 };
 
- // Objekt-Ausrichtung
+ // object orientation
 #define MN_OBJECT_ALIGN \
 MenuItem\
 {\
@@ -633,7 +633,7 @@
 };\
 };
 
- // Bezier-Funktionen
+ // Bezier functions
 #define MN_CLOSE_OBJECT \
 MenuItem\
 {\
@@ -714,7 +714,7 @@
 Text [ en-US ] = ~Reduce Points ; \
 };
 
- // Gruppen-/Kombination-Funktionen
+ // group/combination functions
 #define MN_GROUP \
 MenuItem\
 {\
@@ -804,7 +804,7 @@
 Text [ en-US ] = Presentation ~Object... ; \
 };
 
- // Diverse allgemeine Funktionen
+ // diverse common functions
 #define MN_DELETE \
 MenuItem\
 {\
diff --git a/sd/source/ui/app/sddll.cxx b/sd/source/ui/app/sddll.cxx
index ba7bab9..d76fedf 100644
--- a/sd/source/ui/app/sddll.cxx
+++ b/sd/source/ui/app/sddll.cxx
@@ -102,16 +102,16 @@ void SdDLL::Init()
 // register your controllers here
 RegisterControllers();
 
-// SvDraw-Felder registrieren
+// register SvDraw-Fields
 SdrRegisterFieldClasses();
 
-// 3D-Objekt-Factory eintragen
+// register 3D-Objekt-Factory
 E3dObjFactory();
 
-// ::com::sun::star::form::component::Form-Objekt-Factory eintragen
+// register ::com::sun::star::form::component::Form-Object-Factory
 FmFormObjFactory();
 
-// Objekt-Factory eintragen
+// register Object-Factory
 SdrObjFactory::InsertMakeUserDataHdl(LINK(aSdObjectFactory, 
SdObjectFactory, MakeUserData));
 
 // register your exotic remote controlls here
diff --git a/sd/source/ui/app/sddll2.cxx b/sd/source/ui/app/sddll2.cxx
index 5df0aa7..25d3995 100644
--- a/sd/source/ui/app/sddll2.cxx
+++ b/sd/source/ui/app/sddll2.cxx
@@ -157,13 +157,13 @@ void SdDLL::RegisterControllers()
 SvxCTLTextTbxCtrl::RegisterControl(SID_ATTR_PARA_LEFT_TO_RIGHT, pMod);
 SvxCTLTextTbxCtrl::RegisterControl(SID_ATTR_PARA_RIGHT_TO_LEFT, pMod);
 
-// StatusBarControls registrieren
+// register StatusBarControls
 SvxZoomStatusBarControl::RegisterControl( SID_ATTR_ZOOM, pMod );
 SvxPosSizeStatusBarControl::RegisterControl( SID_ATTR_SIZE, pMod );
 SvxModifyControl::RegisterControl( SID_DOC_MODIFIED, pMod );
 SvxZoomSliderControl::RegisterControl( SID_ATTR_ZOOMSLIDER, pMod );
 
-// MenuControls fuer PopupMenu
+// MenuControls for PopupMenu
 SvxFontMenuControl::RegisterControl( SID_ATTR_CHAR_FONT, pMod );
 SvxFontSizeMenuControl::RegisterControl( SID_ATTR_CHAR_FONTHEIGHT, pMod );
 
diff --git a/sd/source/ui/app/sdxfer.cxx b/sd/source/ui/app/sdxfer.cxx
index 873f56a..0f367f6 100644
--- a/sd/source/ui/app/sdxfer.cxx
+++ b/sd/source/ui/app/sdxfer.cxx
@@ -299,7 +299,7 @@ void SdTransferable::CreateData()
 mbOwnDocument = sal_True;
 }
 
-// Groesse der Source-Seite uebernehmen
+// Use dimension of source page
 SdrPageView*pPgView = mpSdView-GetSdrPageView();
 SdPage* pOldPage = (SdPage*) 

[Libreoffice-commits] core.git: sd/source

2013-03-07 Thread Urs Fässler
 sd/source/ui/app/sdmod.cxx |   50 ++---
 1 file changed, 12 insertions(+), 38 deletions(-)

New commits:
commit a09bb5f4c3c34b6d0e196cd737e74f6fed1acdbb
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Mar 7 14:40:27 2013 +0100

Translation and cleanup of comments in sd/source/ui/app/sdmod.cxx

Change-Id: Icfd5d74f73e0d9d2e4273d8050b7bc2836648aa6

diff --git a/sd/source/ui/app/sdmod.cxx b/sd/source/ui/app/sdmod.cxx
index 91e7789..da75839 100644
--- a/sd/source/ui/app/sdmod.cxx
+++ b/sd/source/ui/app/sdmod.cxx
@@ -65,12 +65,7 @@ SFX_IMPL_INTERFACE(SdModule, SfxModule, 
SdResId(STR_APPLICATIONOBJECTBAR))
 SFX_STATUSBAR_REGISTRATION(SdResId(RID_DRAW_STATUSBAR));
 }
 
-/*
-|*
-|* Ctor
-|*
-\/
-
+// Ctor
 SdModule::SdModule(SfxObjectFactory* pFact1, SfxObjectFactory* pFact2 )
 :   SfxModule( SfxApplication::CreateResManager(sd), sal_False,
   pFact1, pFact2, NULL ),
@@ -84,7 +79,7 @@ SdModule::SdModule(SfxObjectFactory* pFact1, 
SfxObjectFactory* pFact2 )
 bWaterCan(sal_False),
 mpResourceContainer(new ::sd::SdGlobalResourceContainer())
 {
-SetName( rtl::OUString( StarDraw ) );  // Nicht uebersetzen!
+SetName( rtl::OUString( StarDraw ) );  // Do not translate!
 pSearchItem = new SvxSearchItem(SID_SEARCH_ITEM);
 pSearchItem-SetAppFlag(SVX_SEARCHAPP_DRAW);
 StartListening( *SFX_APP() );
@@ -103,14 +98,7 @@ SdModule::SdModule(SfxObjectFactory* pFact1, 
SfxObjectFactory* pFact2 )
 pDevice-SetReferenceDevice ( VirtualDevice::REFDEV_MODE06 );
 }
 
-
-
-/*
-|*
-|* Dtor
-|*
-\/
-
+// Dtor
 SdModule::~SdModule()
 {
 delete pSearchItem;
@@ -140,13 +128,7 @@ SdModule::~SdModule()
 delete static_cast VirtualDevice* ( mpVirtualRefDevice );
 }
 
-
-/*
-|*
-|* get notifications
-|*
-\/
-
+/// get notifications
 void SdModule::Notify( SfxBroadcaster, const SfxHint rHint )
 {
 if( rHint.ISA( SfxSimpleHint ) 
@@ -157,12 +139,7 @@ void SdModule::Notify( SfxBroadcaster, const SfxHint 
rHint )
 }
 }
 
-/*
-|*
-|* Optionen zurueckgeben
-|*
-\/
-
+/// Return options
 SdOptions* SdModule::GetSdOptions(DocumentType eDocType)
 {
 SdOptions* pOptions = NULL;
@@ -197,14 +174,11 @@ SdOptions* SdModule::GetSdOptions(DocumentType eDocType)
 return(pOptions);
 }
 
-/*
-|*
-|* Optionen-Stream fuer interne Options oeffnen und zurueckgeben;
-|* falls der Stream zum Lesen geoeffnet wird, aber noch nicht
-|* angelegt wurde, wird ein 'leeres' RefObject zurueckgegeben
-|*
-\/
-
+/**
+ * Open and return option stream for internal options;
+ * if the stream is opened for reading but does not exist, an 'empty'
+ * RefObject is returned
+ */
 SvStorageStreamRef SdModule::GetOptionStream( const String rOptionName,
   SdOptionStreamMode eMode )
 {
@@ -256,8 +230,8 @@ OutputDevice* SdModule::GetVirtualRefDevice (void)
 }
 
 /** This method is deprecated and only an alias to
-memberGetVirtualRefDevice()/member.  The given argument is ignored.
-*/
+ *   memberGetVirtualRefDevice()/member.  The given argument is ignored.
+ */
 OutputDevice* SdModule::GetRefDevice (::sd::DrawDocShell )
 {
 return GetVirtualRefDevice();
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sd/source

2013-03-07 Thread Urs Fässler
 sd/source/ui/app/sdmod1.cxx |   40 
 1 file changed, 12 insertions(+), 28 deletions(-)

New commits:
commit 5c18df9e69004eeea8f54537468f71c1f726efa1
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Mar 7 14:48:44 2013 +0100

sd/source/ui/app/sdmod1.cxx comment translation and cleanup

Change-Id: I1839f5352f123616ac3373ca7f3488c8b92ce687

diff --git a/sd/source/ui/app/sdmod1.cxx b/sd/source/ui/app/sdmod1.cxx
index e828344..0a2905e 100644
--- a/sd/source/ui/app/sdmod1.cxx
+++ b/sd/source/ui/app/sdmod1.cxx
@@ -95,12 +95,6 @@ private:
 } //end of anonymous namespace
 
 
-/*
-|*
-|* Execute
-|*
-\/
-
 void SdModule::Execute(SfxRequest rReq)
 {
 const SfxItemSet* pSet = rReq.GetArgs();
@@ -116,13 +110,13 @@ void SdModule::Execute(SfxRequest rReq)
 
 case SID_AUTOSPELL_CHECK:
 {
-// automatische Rechtschreibpruefung
+// automatic spell checker
 const SfxPoolItem* pItem;
 if( pSet  SFX_ITEM_SET == pSet-GetItemState(
 SID_AUTOSPELL_CHECK, sal_False, pItem ) )
 {
 sal_Bool bOnlineSpelling = ( (const SfxBoolItem*) pItem 
)-GetValue();
-// am Dokument sichern:
+// save at document:
 ::sd::DrawDocShell* pDocSh = PTR_CAST(::sd::DrawDocShell, 
SfxObjectShell::Current());
 if( pDocSh )
 {
@@ -141,7 +135,7 @@ void SdModule::Execute(SfxRequest rReq)
 FieldUnit eUnit = (FieldUnit)((const 
SfxUInt16Item*)pItem)-GetValue();
 switch( eUnit )
 {
-case FUNIT_MM:  // nur die Einheiten, die auch im 
Dialog stehen
+case FUNIT_MM:  // only the units which are also in 
the dialog
 case FUNIT_CM:
 case FUNIT_INCH:
 case FUNIT_PICA:
@@ -181,7 +175,7 @@ void SdModule::Execute(SfxRequest rReq)
 )
   )
 {
-// am Dokument sichern:
+// save at the document:
 ::sd::DrawDocShell* pDocSh = PTR_CAST(::sd::DrawDocShell, 
SfxObjectShell::Current());
 if ( pDocSh )
 {
@@ -264,8 +258,6 @@ void SdModule::Execute(SfxRequest rReq)
 }
 
 
-
-
 void SdModule::OutlineToImpress (SfxRequest rRequest)
 {
 const SfxItemSet* pSet = rRequest.GetArgs();
@@ -297,7 +289,7 @@ void SdModule::OutlineToImpress (SfxRequest rRequest)
 
 if (pViewSh)
 {
-// AutoLayouts muessen fertig sein
+// AutoLayouts have to be finished
 pDoc-StopWorkStartupDelay();
 
 SfxViewFrame* pViewFrame = pViewSh-GetViewFrame();
@@ -330,19 +322,11 @@ void SdModule::OutlineToImpress (SfxRequest rRequest)
 }
 
 
-
-
-/*
-|*
-|* GetState
-|*
-\/
-
 static bool bOnce = false;
 
 void SdModule::GetState(SfxItemSet rItemSet)
 {
-// Autopilot waehrend der Praesentation disablen
+// disable Autopilot during presentation
 if (rItemSet.GetItemState(SID_SD_AUTOPILOT) != SFX_ITEM_UNKNOWN)
 {
 if (!SvtModuleOptions().IsImpress())
@@ -378,7 +362,7 @@ void SdModule::GetState(SfxItemSet rItemSet)
 }
 }
 
-// der Status von SID_OPENDOC wird von der Basisklasse bestimmt
+// state of SID_OPENDOC is determined by the base class
 if (rItemSet.GetItemState(SID_OPENDOC) != SFX_ITEM_UNKNOWN)
 {
 const SfxPoolItem* pItem = SFX_APP()-GetSlotState(SID_OPENDOC, 
SFX_APP()-GetInterface());
@@ -386,7 +370,7 @@ void SdModule::GetState(SfxItemSet rItemSet)
 rItemSet.Put(*pItem);
 }
 
-// der Status von SID_OPENHYPERLINK wird von der Basisklasse bestimmt
+// state of SID_OPENHYPERLINK is determined by the base class
 if (rItemSet.GetItemState(SID_OPENHYPERLINK) != SFX_ITEM_UNKNOWN)
 {
 const SfxPoolItem* pItem = SFX_APP()-GetSlotState(SID_OPENHYPERLINK, 
SFX_APP()-GetInterface());
@@ -803,20 +787,20 @@ void SdModule::ChangeMedium( ::sd::DrawDocShell* 
pDocShell, SfxViewFrame* pViewF
 
 if( pPrinter  pPrinter-IsValid())
 {
-// Der Printer gibt leider kein exaktes
-// Format (z.B. A4) zurueck
+// Unfortunately, the printer does not provide an exact format
+// like A4
 Size aSize(pPrinter-GetPaperSize());
 Paper ePaper = SvxPaperInfo::GetSvxPaper( aSize, MAP_100TH_MM, 
sal_True);
 
 if (ePaper != PAPER_USER)
 {
-// Korrekte Size holen
+

[Libreoffice-commits] core.git: 3 commits - sd/source

2013-03-07 Thread Urs Fässler
 sd/source/ui/app/sdmod2.cxx  |   52 +++
 sd/source/ui/app/sdpopup.cxx |   40 +
 sd/source/ui/app/tbxww.cxx   |   27 +-
 3 files changed, 45 insertions(+), 74 deletions(-)

New commits:
commit 3acd12a1bbffc9dee9cfdcae92df359a2a8753f0
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Mar 7 14:54:46 2013 +0100

sd/source/ui/app/tbxww.cxx comment translation and cleanup

Change-Id: Ie7bc4ce47c088feeeaf55fb7b2590c5e44a3480e

diff --git a/sd/source/ui/app/tbxww.cxx b/sd/source/ui/app/tbxww.cxx
index 9a12aa3..c668976 100644
--- a/sd/source/ui/app/tbxww.cxx
+++ b/sd/source/ui/app/tbxww.cxx
@@ -39,12 +39,9 @@
 
 SFX_IMPL_TOOLBOX_CONTROL( SdTbxControl, TbxImageItem )
 
-/*
-|*
-|* Klasse fuer Toolbox
-|*
-\/
-
+/**
+ * Class for toolbox
+ */
 SdTbxControl::SdTbxControl( sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox rTbx 
) :
 SfxToolBoxControl( nSlotId, nId, rTbx )
 {
@@ -59,13 +56,11 @@ SfxPopupWindowType SdTbxControl::GetPopupWindowType() const
 return( SFX_POPUPWINDOW_ONTIMEOUT );
 }
 
-/*
-|*
-|* Hier wird das Fenster erzeugt
-|* Lage der Toolbox mit GetToolBox() abfragbar
-|* rItemRect sind die Screen-Koordinaten
-|*
-\/
+/**
+ * We create the window here
+ * You can get the position of the toolbox with GetToolBox()
+ * rItemRect are screen coordinates
+ */
 
 SfxPopupWindow* SdTbxControl::CreatePopupWindow()
 {
@@ -140,8 +135,8 @@ void SdTbxControl::StateChanged( sal_uInt16 nSId,
 if( eState == SFX_ITEM_AVAILABLE )
 {
 TbxImageItem* pItem = PTR_CAST( TbxImageItem, pState );
-// Im StarDesktop kann jetzt auch ein anderes Item ankommen,
-// das nicht ausgewertet werden darf
+// StarDesktop can also receive another item,
+// but it is not allowed to evaluate it
 if( pItem )
 {
 ToolBox rTbx = GetToolBox();
@@ -160,7 +155,7 @@ void SdTbxControl::StateChanged( sal_uInt16 nSId,
  hasBigImages()
);
 
-// !-Operator prueft, ob Image nicht vorhanden ist
+// !-operator checks if image is not present
 if( !!aImage )
 {
 rTbx.SetItemImage( GetId(), aImage );
commit 8d8f62666af44d56339ab3a59b966c61d19075e2
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Mar 7 14:53:41 2013 +0100

sd/source/ui/app/sdpopup.cxx comment translation and cleanup

Change-Id: Ib01cc26d494598def62b34dba52e3c35e9668d10

diff --git a/sd/source/ui/app/sdpopup.cxx b/sd/source/ui/app/sdpopup.cxx
index 6922b79..1102547 100644
--- a/sd/source/ui/app/sdpopup.cxx
+++ b/sd/source/ui/app/sdpopup.cxx
@@ -33,12 +33,9 @@
 #include drawdoc.hxx
 #include DrawDocShell.hxx
 
-/*
-|*
-|* PopupMenu zum Bearbeiten von Feldbefehlen
-|*
-\/
-
+/*
+ * Popup menu for editing of field command
+ */
 SdFieldPopup::SdFieldPopup( const SvxFieldData* pInField, LanguageType 
eLanguage ) :
 PopupMenu   (),
 pField  ( pInField )
@@ -46,22 +43,10 @@ SdFieldPopup::SdFieldPopup( const SvxFieldData* pInField, 
LanguageType eLanguage
 Fill( eLanguage );
 }
 
-/*
-|*
-|* Dtor
-|*
-\/
-
 SdFieldPopup::~SdFieldPopup()
 {
 }
 
-/*
-|*
-|* Fill
-|*
-\/
-
 void SdFieldPopup::Fill( LanguageType eLanguage )
 {
 sal_uInt16 nID = 1;
@@ -80,8 +65,8 @@ void SdFieldPopup::Fill( LanguageType eLanguage )
 else
 CheckItem( 2 );
 
-//SVXDATEFORMAT_APPDEFAULT, // Wird nicht benutzt
-//SVXDATEFORMAT_SYSTEM, // Wird nicht benutzt
+//SVXDATEFORMAT_APPDEFAULT, // is not used
+//SVXDATEFORMAT_SYSTEM, // is not used
 InsertItem( nID++, String( SdResId( STR_STANDARD_SMALL ) ), nStyle );
 InsertItem( nID++, String( SdResId( STR_STANDARD_BIG ) ), nStyle );
 
@@ -112,8 +97,8 @@ void SdFieldPopup::Fill( LanguageType eLanguage )
 else
 CheckItem( 2 );
 
-//SVXTIMEFORMAT_APPDEFAULT, // Wird nicht benutzt
-//SVXTIMEFORMAT_SYSTEM, // Wird nicht benutzt
+//SVXTIMEFORMAT_APPDEFAULT, // is not used
+//SVXTIMEFORMAT_SYSTEM, // is not used
 InsertItem( nID++, 

Translation of German comments of the files in sd/source/filter/eppt/

2013-03-01 Thread Urs Fässler
Translation of German comments of the files in sd/source/filter/eppt/

Regards
Urs

From eeda6483f4c2b9eb3cd845a491783305ebddb30d Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Fri, 1 Mar 2013 11:01:54 +0100
Subject: [PATCH 19/24] translation of German comments in file
 sd/source/filter/grf/sdgrffilter.cxx

Change-Id: Ibab526eae24decc208c74173555e75bb00ac50f9
---
 sd/source/filter/grf/sdgrffilter.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sd/source/filter/grf/sdgrffilter.cxx b/sd/source/filter/grf/sdgrffilter.cxx
index 31f3b57..8a4ac2f 100644
--- a/sd/source/filter/grf/sdgrffilter.cxx
+++ b/sd/source/filter/grf/sdgrffilter.cxx
@@ -224,7 +224,7 @@ sal_Bool SdGRFFilter::Import()
 double fGrfWH = (double) aGrfSize.Width() / aGrfSize.Height();
 double fWinWH = (double) aPagSize.Width() / aPagSize.Height();
 
-// Grafik an Pagesize anpassen (skaliert)
+// adjust graphic to page size (scales)
 if( fGrfWH  fWinWH )
 {
 aGrfSize.Width() = (long) ( aPagSize.Height() * fGrfWH );
@@ -237,7 +237,7 @@ sal_Bool SdGRFFilter::Import()
 }
 }
 
-// Ausgaberechteck fuer Grafik setzen
+// set output rectangle for graphic
 aPos.X() = ( ( aPagSize.Width() - aGrfSize.Width() )  1 ) + pPage-GetLftBorder();
 aPos.Y() = ( ( aPagSize.Height() - aGrfSize.Height() )  1 )  + pPage-GetUppBorder();
 
-- 
1.7.10.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Translation of German comments of the files in sd/source/filter/html/

2013-03-01 Thread Urs Fässler
Translation of German comments of the files in sd/source/filter/html/

Regards
Urs

From ec83e6c015aad134a56a94545b15bf901678a50e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Fri, 1 Mar 2013 11:05:05 +0100
Subject: [PATCH 20/24] translation of German comments in file
 sd/source/filter/html/htmlex.cxx

Change-Id: I8e432ce2f7a68c51da809b3f68c1924fda6b63c8
---
 sd/source/filter/html/htmlex.cxx |  232 +++---
 1 file changed, 115 insertions(+), 117 deletions(-)

diff --git a/sd/source/filter/html/htmlex.cxx b/sd/source/filter/html/htmlex.cxx
index 943645d..9988797 100644
--- a/sd/source/filter/html/htmlex.cxx
+++ b/sd/source/filter/html/htmlex.cxx
@@ -93,12 +93,12 @@ using namespace ::com::sun::star::document;
 
 #define KEY_QUALITY JPG-EXPORT-QUALITY
 
-// Parameter aus Itemset abfragen
+// get parameter from Itemset
 
 #define RESTOHTML( res ) StringToHTMLString(String(SdResId(res)))
 #define S2H( str ) StringToHTMLString( str )
 
-// bei Aenderungen auch NUM_BUTTONS in pubdlg.hxx aendern!!
+// when changing, also change NUM_BUTTONS in pubdlg.hxx!!
 const char *pButtonNames[NUM_BUTTONS] =
 {
 first-inactive.png,
@@ -129,7 +129,7 @@ const char *pButtonNames[NUM_BUTTONS] =
 #define BTN_LESS11
 
 // *
-// Hilfsklasse fuer das simple erzeugen von Dateien lokal/remote
+// Helper class for the simple creation of files local/remote
 // *
 class EasyFile
 {
@@ -149,7 +149,7 @@ public:
 };
 
 // *
-// Hilfsklasse fuer das einbinden von Textattributen in die Html-Ausgabe
+// Helper class for the embedding of text attributes into the html output
 // *
 class HtmlState
 {
@@ -178,7 +178,7 @@ public:
 };
 
 // =
-// alle noch offennen Tags schliessen
+// close all still open tags
 // =
 String HtmlState::Flush()
 {
@@ -195,7 +195,7 @@ String HtmlState::Flush()
 }
 
 // =
-// c'tor mit Defaultfarbe fuer die Seite
+// c'tor with default color for the page
 // =
 HtmlState::HtmlState( Color aDefColor )
 {
@@ -209,7 +209,7 @@ HtmlState::HtmlState( Color aDefColor )
 }
 
 // =
-// aktiviert/deaktiviert Fettdruck
+// enables/disables bold print
 // =
 String HtmlState::SetWeight( bool bWeight )
 {
@@ -225,7 +225,7 @@ String HtmlState::SetWeight( bool bWeight )
 }
 
 // =
-// aktiviert/deaktiviert Italic
+// enables/disables italic
 // =
 String HtmlState::SetItalic( bool bItalic )
 {
@@ -241,7 +241,7 @@ String HtmlState::SetItalic( bool bItalic )
 }
 
 // =
-// aktiviert/deaktiviert Unterstrichen
+// enables/disables underlines
 // =
 String HtmlState::SetUnderline( bool bUnderline )
 {
@@ -257,7 +257,7 @@ String HtmlState::SetUnderline( bool bUnderline )
 }
 
 // =
-// aktiviert/deaktiviert Durchstreichen
+// enables/disables strike through
 // =
 String HtmlState::SetStrikeout( bool bStrike )
 {
@@ -273,7 +273,7 @@ String HtmlState::SetStrikeout( bool bStrike )
 }
 
 // =
-// Setzt die angegebenne Textfarbe
+// Sets the specified text color
 // =
 String HtmlState::SetColor( Color aColor )
 {
@@ -303,7 +303,7 @@ String HtmlState::SetColor( Color aColor )
 }
 
 // =
-// aktiviert/deaktiviert einen Hyperlink
+// enables/disables a hyperlink
 // =
 String HtmlState::SetLink( const String aLink, const String aTarget )
 {
@@ -337,7 +337,7 @@ String HtmlState::SetLink( const String aLink, const String aTarget )
 }
 
 // *
-// class HtmlExport Methoden
+// methods of the class HtmlExport
 // *
 
 static String getParagraphStyle( SdrOutliner* pOutliner, sal_uInt16 nPara )
@@ -357,7 

[PATCH] Translation of German comments of the files in sd/source/filter/ppt/

2013-03-01 Thread Urs Fässler
Translation of German comments of the files in sd/source/filter/ppt/

Regards
Urs

From 34ee897c6a1dc5385d7f444d6453fd9ff2a50b9a Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Fri, 1 Mar 2013 11:07:37 +0100
Subject: [PATCH 22/24] translation of German comments in file
 sd/source/filter/ppt/pptin.cxx

Change-Id: I3849f4078930c88dda19d569d9544851a395a0ea
---
 sd/source/filter/ppt/pptin.cxx |  173 
 1 file changed, 86 insertions(+), 87 deletions(-)

diff --git a/sd/source/filter/ppt/pptin.cxx b/sd/source/filter/ppt/pptin.cxx
index 0925969..05f6d76 100644
--- a/sd/source/filter/ppt/pptin.cxx
+++ b/sd/source/filter/ppt/pptin.cxx
@@ -505,7 +505,7 @@ sal_Bool ImplSdPPTImport::Import()
 if ( mbDocumentFound )
 {
 rStCtrl.Seek( maDocHd.GetRecBegFilePos() + 8 );
-// HyperList lesen / Indexe der einzelnen Eintraege setzen
+// read hyperlist / set indices of the entries
 DffRecordHeader aHyperHd;
 if ( SeekToRec( rStCtrl, PPT_PST_ExObjList, maDocHd.GetRecEndFilePos(), aHyperHd ) )
 {
@@ -597,18 +597,18 @@ sal_Bool ImplSdPPTImport::Import()
 
 ///
 // create layoutstylesheets, set layoutname and stylesheet
-// (nur auf Standard- und Notizseiten)
+// (only on standard and not pages)
 ///
 String aLayoutName( SdResId( STR_LAYOUT_DEFAULT_NAME ) );
 if ( nMasterNum  2 )
 {
 if ( ePgKind == PK_STANDARD )
-{   // Standardseite: Neues Praesentationslayout erzeugen
+{   // standard page: create new presentation layout
 aLayoutName = String( SdResId( STR_LAYOUT_DEFAULT_TITLE_NAME ) );
 aLayoutName += OUString::number( (sal_Int32)( ( nMasterNum + 1 ) / 2 - 1 ) );
 ( (SdStyleSheetPool*)mpDoc-GetStyleSheetPool() )-CreateLayoutStyleSheets( aLayoutName );
 }
-else// Notizseite: Praesentationslayout von der Standardseite verwenden
+else// note page: use presentation layout of standard page
 aLayoutName = ( (SdPage*)mpDoc-GetMasterPage( nMasterNum - 1 ) )-GetName();
 }
 pPage-SetName( aLayoutName );
@@ -994,7 +994,7 @@ sal_Bool ImplSdPPTImport::Import()
 }
 else
 {
-// Das kann bei Dokumentvorlagen vorkommen
+// that can happen by document templates
 eAktPageKind = PPT_SLIDEPAGE;
 SdrPage* pPage = MakeBlancPage( sal_False );
 pSdrModel-InsertPage( pPage );
@@ -1031,7 +1031,7 @@ sal_Bool ImplSdPPTImport::Import()
 rStCtrl.Seek( nFPosMerk );
 }
 ///
-// Handzettel und Notiz-Seiten erzeugen  //
+// create handout and note pages //
 ///
 bOk = mpDoc-CreateMissingNotesAndHandoutPages();
 if ( bOk )
@@ -1047,7 +1047,7 @@ sal_Bool ImplSdPPTImport::Import()
 const PptSlideLayoutAtom* pSlideLayout = GetSlideLayoutAtom();
 if ( pSlideLayout )
 {
-switch ( pSlideLayout-eLayout )// Praesentationslayouts fuer Standard-Seiten
+switch ( pSlideLayout-eLayout )// presentation layout for standard pages
 {
 case PPT_LAYOUT_TITLEANDBODYSLIDE :
 {
@@ -1145,11 +1145,11 @@ sal_Bool ImplSdPPTImport::Import()
 
 case PPT_LAYOUT_BOTTOMROW2COLUMNS :
 case PPT_LAYOUT_BLANCSLIDE :
-case PPT_LAYOUT_MASTERSLIDE :   // Layout der Standard- und Titel-MasterPage
+case PPT_LAYOUT_MASTERSLIDE :   // layout of the standard and title master page
 case PPT_LAYOUT_TITLEMASTERSLIDE :
-case PPT_LAYOUT_MASTERNOTES :   // Layout der Notizen-MasterPage
-case PPT_LAYOUT_NOTESTITLEBODY :// Praesentationslayout fuer Notiz-Seiten
-case PPT_LAYOUT_HANDOUTLAYOUT : // Praesentationslayout fuer Handzettelseiten
+case PPT_LAYOUT_MASTERNOTES :   // layout of the note master page
+case PPT_LAYOUT_NOTESTITLEBODY :// presentation layout for note pages
+case PPT_LAYOUT_HANDOUTLAYOUT : // presentation layout for handout
 eAutoLayout = AUTOLAYOUT_NONE;
  

[Libreoffice-commits] core.git: 2 commits - sd/inc sd/sdi

2013-03-01 Thread Urs Fässler
 sd/inc/app.hrc  |8 
 sd/inc/diadef.h |2 +-
 sd/inc/fadedef.h|4 ++--
 sd/inc/glob.hxx |   10 +-
 sd/inc/helpids.h|2 +-
 sd/inc/prlayout.hxx |6 +++---
 sd/inc/sdattr.hrc   |   18 +-
 sd/inc/sdattr.hxx   |2 +-
 sd/inc/sdiocmpt.hxx |4 ++--
 sd/inc/sdmod.hxx|2 +-
 sd/inc/stlpool.hxx  |2 +-
 sd/sdi/_drvwsh.sdi  |   26 +-
 sd/sdi/grdocsh.sdi  |2 +-
 sd/sdi/outlnvsh.sdi |   20 ++--
 14 files changed, 54 insertions(+), 54 deletions(-)

New commits:
commit a0f8fa87a550caf348cd30bfcecb0fd050564099
Author: Urs Fässler u...@bitzgi.ch
Date:   Fri Mar 1 10:14:00 2013 +0100

translation of German comments of the files in sd/sdi/

Change-Id: Ifc7de73dfeb4e12cbe76237558904f4f1f4b130e

diff --git a/sd/sdi/_drvwsh.sdi b/sd/sdi/_drvwsh.sdi
index 98f1539..a67acf1 100644
--- a/sd/sdi/_drvwsh.sdi
+++ b/sd/sdi/_drvwsh.sdi
@@ -111,7 +111,7 @@ interface DrawView
 ExecMethod = FuSupport ;
 StateMethod = GetMenuState ;
 ]
- // Menue-Messages fuer temporaere Funktionen mit Dialog
+ // Menu messages for temporary functions with dialog
 SID_ATTR_ZOOM // ole : no, status : no
 [
 ExecMethod = FuTemporary ;
@@ -1228,7 +1228,7 @@ interface DrawView
 Export = FALSE ;
 ]
  //
- // Beginn FormSlots
+ // Begin FormSlots
 SID_FM_CREATE_CONTROL
 [
 ExecMethod = FuPermanent ;
@@ -1243,7 +1243,7 @@ interface DrawView
 ExecMethod = ExecCtrl ;
 StateMethod = GetCtrlState ;
 ]
- // Ende FormSlots
+ // End FormSlots
  //
 SID_ATTR_FILL_STYLE // ole : no, status : ?
 [
@@ -1681,9 +1681,9 @@ interface DrawView
 ExecMethod = FuSupport ;
 StateMethod = GetMenuState ;
 ]
- // Problem mit SID_ATTR_FILL_STYLE:
- // frueher XFillStyle, jetzt Property FillStyle (Get/Set)
- // deswegen Export = FALSE !
+ // problem with SID_ATTR_FILL_STYLE:
+ // former XFillStyle, now property FillStyle (Get/Set)
+ // therefore Export = FALSE !
 SID_SETFILLSTYLE // ole : no, status : play rec
 [
 ExecMethod = AttrExec ;
@@ -1705,9 +1705,9 @@ interface DrawView
 ExecMethod = AttrExec ;
 StateMethod = AttrState ;
 ]
- // Problem mit SID_ATTR_LINE_WIDTH:
- // frueher XLineWidth, jetzt Property LineWidth (Get/Set)
- // deswegen Export = FALSE !
+ // problem with SID_ATTR_LINE_WIDTH:
+ // former XLineWidth, now property LineWidth (Get/Set)
+ // therefore Export = FALSE !
 SID_SETLINEWIDTH // ole : no, status : play rec
 [
 ExecMethod = AttrExec ;
@@ -1720,9 +1720,9 @@ interface DrawView
 StateMethod = AttrState ;
 ]
  //DB: FillColor - SetFillColor
- // Problem mit SID_ATTR_FILL_COLOR:
- // frueher XFillColor, jetzt Property FillColor (Get/Set)
- // deswegen Export = FALSE !
+ // problem with SID_ATTR_FILL_COLOR:
+ // former XFillColor, now property FillColor (Get/Set)
+ // therefore Export = FALSE !
 SID_SETFILLCOLOR // ole : no, status : play rec
 [
 ExecMethod = AttrExec ;
@@ -1939,7 +1939,7 @@ interface DrawView
 ExecMethod = FuTemporary ;
 StateMethod = GetMenuState ;
 ]
- // Slots in der Optionsleiste
+ // slots in the option pane
 SID_BEZIER_EDIT // ole : no, status : ?
 [
 ExecMethod = FuSupport ;
diff --git a/sd/sdi/grdocsh.sdi b/sd/sdi/grdocsh.sdi
index ed508a6..6f17114 100644
--- a/sd/sdi/grdocsh.sdi
+++ b/sd/sdi/grdocsh.sdi
@@ -18,7 +18,7 @@
 
 interface GraphicDocument : DrawDocument
 [
-uuid ( D7474100-ACDF-11D0-89CB-008029E4B0B1 ) ; // erzeug am 04.04.97
+uuid ( D7474100-ACDF-11D0-89CB-008029E4B0B1 ) ; // created at 04.04.97
 ]
 {
 }
diff --git a/sd/sdi/outlnvsh.sdi b/sd/sdi/outlnvsh.sdi
index dbe34ed..68c3b52 100644
--- a/sd/sdi/outlnvsh.sdi
+++ b/sd/sdi/outlnvsh.sdi
@@ -250,8 +250,8 @@ interface OutlineView
 ExecMethod = FuTemporaryModify ;
 StateMethod = GetMenuState ;
 ]
- // Vorlagen
- // kein Menueeintrag
+ // Templates
+ // no menu entry
 SID_STYLE_FAMILY2 // ole : no, status : ?
 [
 ExecMethod = FuTemporary ;
@@ -266,14 +266,14 @@ interface OutlineView
 GroupId = GID_DOCUMENT ;
 Cachable ;
 ]
- // Vorlagen
- // kein Menueeintrag
+ // Templates
+ // no menu entry
 SID_STYLE_FAMILY5 // ole : no, status : ?
 [
 ExecMethod = FuTemporary ;
 StateMethod = GetAttrState ;
 ]
- // kein Menueeintrag
+ // no menu entry
 SID_STYLE_EDIT // ole : no, status : ?
 [
 ExecMethod = FuTemporary ;
@@ -281,7 +281,7 @@ interface OutlineView
 GroupId = GID_DOCUMENT ;
 Cachable ;
 ]
- // kein 

[Libreoffice-commits] core.git: 4 commits - sd/source

2013-03-01 Thread Urs Fässler
 sd/source/core/glob.src |   12 ++--
 sd/source/core/pglink.cxx   |   14 ++--
 sd/source/core/sdiocmpt.cxx |2 
 sd/source/core/sdpage.cxx   |  132 ++--
 4 files changed, 80 insertions(+), 80 deletions(-)

New commits:
commit 4c5e85403955da8bbafaa4b58486130e12e73c65
Author: Urs Fässler u...@bitzgi.ch
Date:   Fri Mar 1 10:53:55 2013 +0100

translation of German comments in file sd/source/core/sdpage.cxx

Change-Id: If75c2f867cbbb0b1d0d3ed83f4439da5f1875eeb

diff --git a/sd/source/core/sdpage.cxx b/sd/source/core/sdpage.cxx
index 399c1fd..cd7d6c1 100644
--- a/sd/source/core/sdpage.cxx
+++ b/sd/source/core/sdpage.cxx
@@ -106,9 +106,9 @@ SdPage::SdPage(SdDrawDocument rNewDoc, StarBASIC* pBasic, 
sal_Bool bMasterPage)
 ,   mfTransitionDuration(2.0)
 ,   mbIsPrecious(true)
 {
-// Der Layoutname der Seite wird von SVDRAW benutzt, um die Praesentations-
-// vorlagen der Gliederungsobjekte zu ermitteln. Darum enthaelt er bereits
-// den Bezeichner fuer die Gliederung (STR_LAYOUT_OUTLINE).
+// The name of the layout of the page is used by SVDRAW to determine the
+// presentation template of the outline objects. Therefore, it already
+// contains the designator for the outline (STR_LAYOUT_OUTLINE).
 OUStringBuffer aBuf(SdResId(STR_LAYOUT_DEFAULT_NAME).toString());
 
aBuf.append(SD_LT_SEPARATOR).append(SdResId(STR_LAYOUT_OUTLINE).toString());
 maLayoutName = aBuf.makeStringAndClear();
@@ -344,7 +344,7 @@ SdrObject* SdPage::CreatePresObj(PresObjKind eObjKind, 
sal_Bool bVertical, const
 
 case PRESOBJ_HANDOUT:
 {
-//Erste Standardseite am SdrPageObj vermerken
+// Save the first standard page at SdrPageObj
 // #i105146# We want no content to be displayed for PK_HANDOUT,
 // so just never set a page as content
 pSdrObj = new SdrPageObj(0);
@@ -353,7 +353,7 @@ SdrObject* SdPage::CreatePresObj(PresObjKind eObjKind, 
sal_Bool bVertical, const
 
 case PRESOBJ_PAGE:
 {
-//Notizseite am SdrPageObj vermerken
+// Save note pages at SdrPageObj
 sal_uInt16 nDestPageNum(GetPageNum());
 
 if(nDestPageNum)
@@ -411,8 +411,8 @@ SdrObject* SdPage::CreatePresObj(PresObjKind eObjKind, 
sal_Bool bVertical, const
 
 if (mbMaster)
 {
-// Bei Praesentationsobjekten auf der MasterPage soll die
-// Groesse vom Benutzwer frei waehlbar sein
+// The size of presentation objects on the master page have to
+// be freely selectable by the user.
 
 // potential problem: This action was still NOT
 // adapted for vertical text. This sure needs to be done.
@@ -490,12 +490,12 @@ SdrObject* SdPage::CreatePresObj(PresObjKind eObjKind, 
sal_Bool bVertical, const
 {
 SdrLayerAdmin rLayerAdmin = pModel-GetLayerAdmin();
 
-// Hintergrundobjekte der MasterPage
+// background objects of the master page
 pSdrObj-SetLayer( rLayerAdmin.
 GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), sal_False) );
 }
 
-// Objekt am StyleSheet anmelden
+// Subscribe object at the style sheet
 // Set style only when one was found (as in 5.2)
 if( mePageKind != PK_HANDOUT )
 {
@@ -553,8 +553,8 @@ SdrObject* SdPage::CreatePresObj(PresObjKind eObjKind, 
sal_Bool bVertical, const
 
 /*
 |*
-|* Es werden Praesentationsobjekte auf der Page erzeugt.
-|* Alle Praesentationsobjekte erhalten einen UserCall auf die Page.
+|* Creates presentation objects on the master page.
+|* All presentation objects get a UserCall to the page.
 |*
 \/
 
@@ -670,9 +670,9 @@ SdStyleSheet* SdPage::getPresentationStyle( sal_uInt32 
nHelpId ) const
 
 /*
 |*
-|* Das Praesentationsobjekt rObj hat sich geaendert und wird nicht mehr
-|* durch das Praesentationsobjekt der MasterPage referenziert.
-|* Der UserCall wird geloescht.
+|* The presentation object rObj has changed and is no longer referenzed by the
+|* presentation object of the master page.
+|* The UserCall is deleted.
 |*
 \/
 
@@ -708,8 +708,8 @@ void SdPage::Changed(const SdrObject rObj, SdrUserCallType 
eType, const Rectang
 }
 else if (pModel)
 {
-// MasterPage-Objekt wurde veraendert, daher
-// Objekte auf allen Seiten anpassen
+// Object of the master page changed, therefore adjust
+// object on all pages
 sal_uInt16 

[Libreoffice-commits] core.git: 6 commits - sd/source

2013-03-01 Thread Urs Fässler
 sd/source/core/sdpage2.cxx|   68 -
 sd/source/core/stlpool.cxx|   79 ++
 sd/source/filter/eppt/eppt.cxx|   50 +-
 sd/source/filter/eppt/eppt.hxx|   16 +++---
 sd/source/filter/eppt/epptso.cxx  |   43 +++-
 sd/source/filter/eppt/escherex.cxx|2 
 sd/source/filter/eppt/pptx-epptbase.cxx   |6 +-
 sd/source/filter/eppt/pptx-stylesheet.cxx |4 -
 sd/source/filter/eppt/pptx-text.cxx   |   24 -
 sd/source/filter/eppt/text.hxx|   12 ++--
 10 files changed, 150 insertions(+), 154 deletions(-)

New commits:
commit 8eb64e21a826ddde37356d0cb22dbff408efd2c9
Author: Urs Fässler u...@bitzgi.ch
Date:   Fri Mar 1 11:01:10 2013 +0100

translation of German comments in file sd/source/filter/eppt/pptx-text.cxx

Change-Id: Ibf2ef88a200699bea456b916fd5e59392d1f19e1

diff --git a/sd/source/filter/eppt/pptx-text.cxx 
b/sd/source/filter/eppt/pptx-text.cxx
index ff5532c..b344101 100644
--- a/sd/source/filter/eppt/pptx-text.cxx
+++ b/sd/source/filter/eppt/pptx-text.cxx
@@ -460,7 +460,7 @@ sal_uInt32 PortionObj::ImplCalculateTextPositions( 
sal_uInt32 nCurrentTextPositi
 }
 
 //  ---
-// Rueckgabe:   0 = kein TextField
+// Return:  0 = no TextField
 //  bit28-31   text field type :
 //  1 = Date
 //  2 = Time
@@ -501,7 +501,7 @@ sal_uInt32 PortionObj::ImplGetTextField( 
::com::sun::star::uno::Reference ::com
 {
 sal_Bool bBool = sal_False;
 aAny = bBool;
-if ( !bBool )  // Fixed DateFields gibt es 
in PPT nicht
+if ( !bBool )  // Fixed DateFields does 
not exist in PPT
 {
 if ( GetPropertyValue( aAny, 
xFieldPropSet, rtl::OUString( Format ) ), sal_True )
 {
@@ -893,17 +893,17 @@ void ParagraphObj::ImplGetNumberingLevel( 
PPTExBulletProvider rBuProv, sal_Int1
 
 if ( !aFontDesc.Name.isEmpty() )
 {
-nParaFlags |= 0x90; // wir geben den Font und den 
Charset vor
+nParaFlags |= 0x90; // we define the font and 
charset
 }
 }
-case SVX_NUM_CHARS_UPPER_LETTER :   // zaehlt von a-z, 
aa - az, ba - bz, ...
+case SVX_NUM_CHARS_UPPER_LETTER :   // count from a-z, 
aa - az, ba - bz, ...
 case SVX_NUM_CHARS_LOWER_LETTER :
 case SVX_NUM_ROMAN_UPPER :
 case SVX_NUM_ROMAN_LOWER :
 case SVX_NUM_ARABIC :
-case SVX_NUM_PAGEDESC : // Numerierung aus 
der Seitenvorlage
+case SVX_NUM_PAGEDESC : // numbering from 
the page template
 case SVX_NUM_BITMAP :
-case SVX_NUM_CHARS_UPPER_LETTER_N : // zaehlt von  
a-z, aa-zz, aaa-zzz
+case SVX_NUM_CHARS_UPPER_LETTER_N : // count from a-z, 
aa-zz, aaa-zzz
 case SVX_NUM_CHARS_LOWER_LETTER_N :
 {
 if ( nNumberingType != SVX_NUM_CHAR_SPECIAL )
@@ -1145,17 +1145,17 @@ void ParagraphObj::ImplConstruct( const ParagraphObj 
rParagraphObj )
 nBulletFlags = rParagraphObj.nBulletFlags;
 sPrefix = rParagraphObj.sPrefix;
 sSuffix = rParagraphObj.sSuffix;
-sGraphicUrl = rParagraphObj.sGraphicUrl;// String auf eine 
Graphic
+sGraphicUrl = rParagraphObj.sGraphicUrl;// String to a graphic
 aBuGraSize = rParagraphObj.aBuGraSize;
-nNumberingType = rParagraphObj.nNumberingType;  // in wirlichkeit ist 
dies ein SvxEnum
+nNumberingType = rParagraphObj.nNumberingType;  // this is actually a 
SvxEnum
 nHorzAdjust = rParagraphObj.nHorzAdjust;
 nBulletColor = rParagraphObj.nBulletColor;
 nBulletOfs = rParagraphObj.nBulletOfs;
-nStartWith = rParagraphObj.nStartWith;  // Start der 
nummerierung
+nStartWith = rParagraphObj.nStartWith;  // start of numbering
 nTextOfs = rParagraphObj.nTextOfs;
-nBulletRealSize = rParagraphObj.nBulletRealSize;// GroessenVerhaeltnis 
in Proz
-nDepth = rParagraphObj.nDepth;  // aktuelle tiefe
-cBulletId = rParagraphObj.cBulletId;// wenn Numbering Type 
== CharSpecial
+nBulletRealSize = rParagraphObj.nBulletRealSize;// scale in percent
+nDepth = rParagraphObj.nDepth;  // actual 

[PATCH] translation of german message in dtrans/source/cnttype/wbench/testcnttype.cxx

2013-02-21 Thread Urs Fässler
Hello,
patch with a translation of the German messages in the test program
dtrans/source/cnttype/wbench/testcnttype.cxx.

Regards
Urs

From 70527240a96872b0035b62e8dca77f9f05666b3b Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Thu, 21 Feb 2013 16:43:22 +0100
Subject: [PATCH] Translation of messages in test program

Change-Id: I8588f5bad12561b891956cde44daeb4c81f815c3
---
 dtrans/source/cnttype/wbench/testcnttype.cxx |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/dtrans/source/cnttype/wbench/testcnttype.cxx b/dtrans/source/cnttype/wbench/testcnttype.cxx
index 61a91e6..e7fe844 100644
--- a/dtrans/source/cnttype/wbench/testcnttype.cxx
+++ b/dtrans/source/cnttype/wbench/testcnttype.cxx
@@ -116,7 +116,7 @@ sal_Bool processCntTypesAndWriteResultIntoFile( char* fname, vector string  v
 {
 try
 {
-fprintf( fstream, Gelesen: %s\n, iter-c_str( ) );
+fprintf( fstream, Read: %s\n, iter-c_str( ) );
 
 Reference XMimeContentType  xMCntTyp = cnttypeFactory-createMimeContentType( OUString::createFromAscii( iter-c_str( ) ) );
 
@@ -134,15 +134,15 @@ sal_Bool processCntTypesAndWriteResultIntoFile( char* fname, vector string  v
 }
 catch( IllegalArgumentException ex )
 {
-fwprintf( fstream, OUString(Fehlerhafter Content-Type gelesen!!!\n\n) );
+fwprintf( fstream, OUString(Read incorrect content type!\n\n) );
 }
 catch( NoSuchElementException )
 {
-fwprintf( fstream, OUString(Parameterwert nicht vorhanden\n) );
+fwprintf( fstream, OUString(Value of parameter not available\n) );
 }
 catch( ... )
 {
-fwprintf( fstream, OUString(Unbekannter Fehler!!!\n\n) );
+fwprintf( fstream, OUString(Unknown error!\n\n) );
 }
 
 fwprintf( fstream, OUString(\n#\n\n) );
-- 
1.7.10.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Translation of German (test) string

2013-02-21 Thread Urs Fässler
Hello,
I translated a German string in
dtrans/source/win32/workbench/test_wincb.cxx. I hope it does not break
any test or so, but I did not found the string Fahrrad any other file.

Regards
Urs

From 76582d1a21b226a00584c553fe324dc90c19bf9c Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Thu, 21 Feb 2013 17:32:40 +0100
Subject: [PATCH] Translation of German (test) string

Change-Id: Ibcc4fc86497a186eec7e508d58c36dde4a3d3129
---
 dtrans/source/win32/workbench/test_wincb.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/dtrans/source/win32/workbench/test_wincb.cxx b/dtrans/source/win32/workbench/test_wincb.cxx
index 9839af5..b32a56f 100644
--- a/dtrans/source/win32/workbench/test_wincb.cxx
+++ b/dtrans/source/win32/workbench/test_wincb.cxx
@@ -147,7 +147,7 @@ private:
 
 CTransferable::CTransferable( ) :
 m_FlavorList( 1 ),
-m_Data( OUString(Ich habe mir ein neues Fahrrad gekauft!) )
+m_Data( OUString(I bought a new bike!) )
 {
 DataFlavor df;
 
-- 
1.7.10.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] translation of german comment in file dtrans/source/win32/clipb/WinClipbImpl.cxx

2013-02-15 Thread Urs Fässler
Hello,
I translated the (only) german comment in the file
dtrans/source/win32/clipb/WinClipbImpl.cxx

Regards
Urs

From 7454d8ad180504ea2e50a52fe4a08ebc329db33f Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Thu, 14 Feb 2013 18:17:44 +0100
Subject: [PATCH] Translation of german comment

Change-Id: I2876e33ccfd5dd7b33747d77a4cdaaa03bd01de9
---
 dtrans/source/win32/clipb/WinClipbImpl.cxx |   19 +--
 1 file changed, 9 insertions(+), 10 deletions(-)

diff --git a/dtrans/source/win32/clipb/WinClipbImpl.cxx b/dtrans/source/win32/clipb/WinClipbImpl.cxx
index 167e889..ff89e14 100644
--- a/dtrans/source/win32/clipb/WinClipbImpl.cxx
+++ b/dtrans/source/win32/clipb/WinClipbImpl.cxx
@@ -180,16 +180,15 @@ sal_Int8 SAL_CALL CWinClipbImpl::getRenderingCapabilities(  ) throw( RuntimeExce
 
 void SAL_CALL CWinClipbImpl::flushClipboard( ) throw( RuntimeException )
 {
-// sollte eigentlich hier stehen: ClearableMutexGuard aGuard( m_ClipContentMutex );
-// geht aber nicht, da FlushClipboard zurückruft und das DataObject
-// freigibt und damit würde es einen Deadlock in onReleaseDataObject geben
-// FlushClipboard muß synchron sein, damit das runterfahren ggf. erst weitergeht,
-// wenn alle Clipboard-Formate gerendert wurden
-// die Abfrage ist nötig, damit nur geflusht wird, wenn wir wirklich Clipboardowner
-// sind (ich weiss nicht genau was passiert, wenn man flusht und nicht Clipboard
-// owner ist).
-// eventuell kann man aber die Abfrage in den Clipboard STA Thread verlagern, indem
-// man sich dort das DataObject merkt und vor dem flushen OleIsCurrentClipboard ruft
+// actually it should be ClearableMutexGuard aGuard( m_ClipContentMutex );
+// but it does not work since FlushClipboard does a callback and frees DataObject
+// which results in a deadlock in onReleaseDataObject.
+// FlushClipboard had to be synchronous in order to prevent shutdown until all
+// clipboard-formats are rendered.
+// The request is needed to prevent flushing if we are not clipboard owner (it is
+// not known what happens if we flush but are not clipboard owner).
+// It may be possible to move the request to the clipboard STA thread by saving the
+// DataObject and call OleIsCurrentClipboard before flushing.
 
 if ( NULL != m_pCurrentClipContent )
 m_MtaOleClipboard.flushClipboard( );
-- 
1.7.10.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] translation of german comment in file dtrans/source/win32/clipb/WinClipbImpl.cxx

2013-02-14 Thread Urs Fässler
Hi,
translation of the (only) german comment in the file
dtrans/source/win32/clipb/WinClipbImpl.cxx

Rgeards
Urs

From 3baf9a8197f09246a3beb9f14a9a0e57696ef3f7 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Thu, 14 Feb 2013 16:36:06 +0100
Subject: [PATCH] Translation of german comment

Change-Id: I2876e33ccfd5dd7b33747d77a4cdaaa03bd01de9
---
 dtrans/source/win32/clipb/WinClipbImpl.cxx |   19 +--
 1 file changed, 9 insertions(+), 10 deletions(-)

diff --git a/dtrans/source/win32/clipb/WinClipbImpl.cxx b/dtrans/source/win32/clipb/WinClipbImpl.cxx
index 167e889..76e4c64 100644
--- a/dtrans/source/win32/clipb/WinClipbImpl.cxx
+++ b/dtrans/source/win32/clipb/WinClipbImpl.cxx
@@ -180,16 +180,15 @@ sal_Int8 SAL_CALL CWinClipbImpl::getRenderingCapabilities(  ) throw( RuntimeExce
 
 void SAL_CALL CWinClipbImpl::flushClipboard( ) throw( RuntimeException )
 {
-// sollte eigentlich hier stehen: ClearableMutexGuard aGuard( m_ClipContentMutex );
-// geht aber nicht, da FlushClipboard zurückruft und das DataObject
-// freigibt und damit würde es einen Deadlock in onReleaseDataObject geben
-// FlushClipboard muß synchron sein, damit das runterfahren ggf. erst weitergeht,
-// wenn alle Clipboard-Formate gerendert wurden
-// die Abfrage ist nötig, damit nur geflusht wird, wenn wir wirklich Clipboardowner
-// sind (ich weiss nicht genau was passiert, wenn man flusht und nicht Clipboard
-// owner ist).
-// eventuell kann man aber die Abfrage in den Clipboard STA Thread verlagern, indem
-// man sich dort das DataObject merkt und vor dem flushen OleIsCurrentClipboard ruft
+// actually it should be ClearableMutexGuard aGuard( m_ClipContentMutex );
+// but it does not work since FlushClipboard does a callback and frees DataObject
+// which results in a deadlock in onReleaseDataObject.
+// FlushClipboard had to be synchron in order to prevent shutdown until all
+// clipboard-formats are redered.
+// The request is needed to prevent flushing if we are not clipboard owner (it is
+// not known what happens if we flush but aren't clipoard owner).
+// It may be possible to move the request to the clipboard STA thread by saving the
+// DataObject and call OleIsCurrentClipboard bevore flushing.
 
 if ( NULL != m_pCurrentClipContent )
 m_MtaOleClipboard.flushClipboard( );
-- 
1.7.10.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: dtrans/source

2013-02-14 Thread Urs Fässler
 dtrans/source/win32/clipb/WinClipbImpl.cxx |   19 +--
 1 file changed, 9 insertions(+), 10 deletions(-)

New commits:
commit 1e95602e5d566468ed075b1813e21ba08039b2db
Author: Urs Fässler u...@bitzgi.ch
Date:   Thu Feb 14 16:36:06 2013 +0100

Translation of german comment

Change-Id: I2876e33ccfd5dd7b33747d77a4cdaaa03bd01de9

diff --git a/dtrans/source/win32/clipb/WinClipbImpl.cxx 
b/dtrans/source/win32/clipb/WinClipbImpl.cxx
index 167e889..76e4c64 100644
--- a/dtrans/source/win32/clipb/WinClipbImpl.cxx
+++ b/dtrans/source/win32/clipb/WinClipbImpl.cxx
@@ -180,16 +180,15 @@ sal_Int8 SAL_CALL 
CWinClipbImpl::getRenderingCapabilities(  ) throw( RuntimeExce
 
 void SAL_CALL CWinClipbImpl::flushClipboard( ) throw( RuntimeException )
 {
-// sollte eigentlich hier stehen: ClearableMutexGuard aGuard( 
m_ClipContentMutex );
-// geht aber nicht, da FlushClipboard zurückruft und das DataObject
-// freigibt und damit würde es einen Deadlock in onReleaseDataObject geben
-// FlushClipboard muß synchron sein, damit das runterfahren ggf. erst 
weitergeht,
-// wenn alle Clipboard-Formate gerendert wurden
-// die Abfrage ist nötig, damit nur geflusht wird, wenn wir wirklich 
Clipboardowner
-// sind (ich weiss nicht genau was passiert, wenn man flusht und nicht 
Clipboard
-// owner ist).
-// eventuell kann man aber die Abfrage in den Clipboard STA Thread 
verlagern, indem
-// man sich dort das DataObject merkt und vor dem flushen 
OleIsCurrentClipboard ruft
+// actually it should be ClearableMutexGuard aGuard( m_ClipContentMutex );
+// but it does not work since FlushClipboard does a callback and frees 
DataObject
+// which results in a deadlock in onReleaseDataObject.
+// FlushClipboard had to be synchron in order to prevent shutdown until all
+// clipboard-formats are redered.
+// The request is needed to prevent flushing if we are not clipboard owner 
(it is
+// not known what happens if we flush but aren't clipoard owner).
+// It may be possible to move the request to the clipboard STA thread by 
saving the
+// DataObject and call OleIsCurrentClipboard bevore flushing.
 
 if ( NULL != m_pCurrentClipContent )
 m_MtaOleClipboard.flushClipboard( );
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


License statement

2013-02-14 Thread Urs Fässler
Ok, here it is:

   All of my past  future contributions to LibreOffice may be
   licensed under the MPL/LGPLv3+ dual license

Regards
Urs

Am Donnerstag, den 14.02.2013, 19:58 +0100 schrieb Markus Mohrhard:
 Hey,
 
 2013/2/14 Urs Fässler u...@bitzgi.ch:
  Hi,
  translation of the (only) german comment in the file
  dtrans/source/win32/clipb/WinClipbImpl.cxx
 
 
 Looks nice and pushed to master. It seems we have no license statement
 from you. Could you please send one to the mailing list?
 
 Regards,
 Markus
 ___
 LibreOffice mailing list
 LibreOffice@lists.freedesktop.org
 http://lists.freedesktop.org/mailman/listinfo/libreoffice


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice
From 8b21434d884bfaf3e11e566dd1dee3c14fadc53b Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Urs=20F=C3=A4ssler?= u...@bitzgi.ch
Date: Fri, 1 Mar 2013 10:58:56 +0100
Subject: [PATCH 15/24] translation of German comments in files
 sd/source/filter/eppt/eppt.*

Change-Id: Ied95b179972106402fde3f9d82f6c4844571fa3a
---
 sd/source/filter/eppt/eppt.cxx |   50 
 sd/source/filter/eppt/eppt.hxx |   16 ++---
 2 files changed, 33 insertions(+), 33 deletions(-)

diff --git a/sd/source/filter/eppt/eppt.cxx b/sd/source/filter/eppt/eppt.cxx
index 5d8959a..d98cdda 100644
--- a/sd/source/filter/eppt/eppt.cxx
+++ b/sd/source/filter/eppt/eppt.cxx
@@ -90,7 +90,7 @@ void PPTWriter::exportPPTPre( const std::vector com::sun::star::beans::Property
 if ( !mrStg.Is() )
 return;
 
-// MasterPages + Slides und Notizen + NotesMasterPage
+// master pages + slides and notes + notes master page
 mnDrawings = mnMasterPages + ( mnPages  1 ) + 1;
 
 if ( mXStatusIndicator.is() )
@@ -169,9 +169,9 @@ void PPTWriter::ImplWriteSlide( sal_uInt32 nPageNum, sal_uInt32 nMasterNum, sal_
 mpPptEscherEx-OpenContainer( EPP_Slide );
 mpPptEscherEx-AddAtom( 24, EPP_SlideAtom, 2 );
 *mpStrm  rLayout.nLayout;
-mpStrm-Write( rLayout.nPlaceHolder, 8 );   // placeholderIDs ( 8Stueck )
-*mpStrm  (sal_uInt32)(nMasterNum | 0x8000)// master ID ( ist gleich 0x8000 bei einer masterpage   )
- (sal_uInt32)nPageNum + 0x100 // notes ID ( ist gleich null wenn keine notizen vorhanden )
+mpStrm-Write( rLayout.nPlaceHolder, 8 );   // placeholderIDs (8 parts)
+*mpStrm  (sal_uInt32)(nMasterNum | 0x8000)// master ID (equals 0x8000 on a master page)
+ (sal_uInt32)nPageNum + 0x100 // notes ID (equals null if no notes are present)
  nMode
  (sal_uInt16)0;   // padword
 
@@ -185,12 +185,12 @@ void PPTWriter::ImplWriteSlide( sal_uInt32 nPageNum, sal_uInt32 nMasterNum, sal_
 {
 switch ( *(sal_Int32*)aAny.getValue() )
 {
-case 1 :// automatisch
+case 1 :// automatic
 mnDiaMode++;
-case 2 :// halbautomatisch
+case 2 :// semi-automatic
 mnDiaMode++;
 default :
-case 0 :// manuell
+case 0 :// manual
 break;
 }
 }
@@ -226,7 +226,7 @@ void PPTWriter::ImplWriteSlide( sal_uInt32 nPageNum, sal_uInt32 nMasterNum, sal_
 sal_uInt8   nDirection = 0;
 sal_uInt8   nTransitionType = 0;
 sal_uInt16  nBuildFlags = 1;// advange by mouseclick
-sal_Int32   nSlideTime = 0; // muss noch !!!
+sal_Int32   nSlideTime = 0; // still has to !!!
 sal_uInt8   nSpeed = 1;
 
 if ( GetPropertyValue( aAny, mXPagePropSet, rtl::OUString( Speed ) ) )
@@ -277,7 +277,7 @@ void PPTWriter::ImplWriteSlide( sal_uInt32 nPageNum, sal_uInt32 nMasterNum, sal_
 mpPptEscherEx-OpenContainer( EPP_PPDrawing );
 mpPptEscherEx-OpenContainer( ESCHER_DgContainer );
 mpPptEscherEx-EnterGroup(0,0);
-ImplWritePage( rLayout, aSolverContainer, NORMAL, sal_False, nPageNum );// Die Shapes der Seite werden im PPT Dok. erzeugt
+ImplWritePage( rLayout, aSolverContainer, NORMAL, sal_False, nPageNum );// the shapes of the pages are created in the PPT document
 mpPptEscherEx-LeaveGroup();
 
 if ( bHasBackground )
@@ -358,8 +358,8 @@ void PPTWriter::ImplWriteSlideMaster( sal_uInt32 nPageNum, Reference XPropertyS
 mpPptEscherEx-AddAtom( 24, EPP_SlideAtom, 2 );
 *mpStrm  (sal_Int32)EPP_LAYOUT_TITLEANDBODYSLIDE  // slide layout - title and body slide
  (sal_uInt8)1  (sal_uInt8)2  (sal_uInt8)0  (sal_uInt8)0  (sal_uInt8)0  (sal_uInt8)0  (sal_uInt8)0  (sal_uInt8)0 // placeholderID
- (sal_uInt32)0// master ID ( ist gleich null bei einer masterpage )
- (sal_uInt32)0// notes ID ( ist gleich null wenn keine notizen vorhanden )
+ (sal_uInt32)0// master ID (equals null at a master page)
+ (sal_uInt32)0// notes ID (equals null if no notes are present)
  (sal_uInt16)0// Bit 1: Follow master objects, Bit 2: Follow master scheme, Bit 3: Follow master background
  (sal_uInt16)0;   // padword
 
@@ -418,7 +418,7 @@ void PPTWriter::ImplWriteSlideMaster( sal_uInt32 nPageNum, Reference XPropertyS
 mpPptEscherEx-OpenContainer( ESCHER_DgContainer );
 
 mpPptEscherEx-EnterGroup(0,0);
-ImplWritePage( GetLayout( 0 ), aSolverContainer, MASTER, sal_True );// Die Shapes der Seite werden im PPT Dok. erzeugt
+ImplWritePage( GetLayout( 0 ), aSolverContainer, MASTER, sal_True );// the shapes of the pages are 

[PATCH] Translation of German comments of the files in sd/source/filter/grf/

2013-03-01 Thread Urs Fässler
Translation of German comments of the files in sd/source/filter/grf/

Regards
Urs
